/**
 * Class to optimize HTML scripts by deduplicating and consolidating script tags.
 */
declare class HtmlScriptsOptimizer {
    private static instance;
    private inputDirectory;
    /**
     * Private constructor to prevent direct class instantiation.
     * @param {string} inputDirectory - The directory containing HTML files to optimize.
     */
    private constructor();
    /**
     * Returns the singleton instance of HtmlScriptsOptimizer.
     * @param {string} inputDirectory - The directory containing HTML files to optimize.
     * @returns {HtmlScriptsOptimizer} The singleton instance.
     */
    static getInstance(inputDirectory: string): HtmlScriptsOptimizer;
    /**
     * Recursively reads all directories from the specified directory.
     * @param {string} dir - The directory to read subdirectories from.
     * @returns {string[]} An array of directory paths.
     */
    private readDirectoriesRecursive;
    /**
     * Reads all HTML files from the specified directory.
     * @param {string} dir - The directory to read HTML files from.
     * @returns {string[]} An array of HTML file paths.
     */
    private readHtmlFiles;
    /**
     * Extracts script tags from the given HTML content.
     * @param {string} htmlContent - The HTML content to extract script tags from.
     * @returns {string[]} An array of script tag contents.
     */
    private extractScriptTags;
    /**
     * Removes script tags from the given HTML content.
     * @param {string} htmlContent - The HTML content to remove script tags from.
     * @returns {string} The HTML content without script tags.
     */
    private removeScriptTags;
    /**
     * Inserts unique script tags wrapped in a single <script> tag at the top of the specified HTML file.
     * @param {string} filePath - The path to the HTML file to insert script tags into.
     * @param {Set<string>} scriptTags - The set of unique script tag contents to insert.
     */
    private insertUniqueScriptTags;
    /**
     * Main function to optimize scripts by deduplicating and consolidating script tags across multiple HTML files.
     */
    run(): void;
}
export default HtmlScriptsOptimizer;
