/**
 * Class to optimize HTML styles by deduplicating and consolidating style tags.
 */
declare class HtmlStylesOptimizer {
    private static instance;
    private inputDirectory;
    /**
     * Private constructor to prevent direct class instantiation.
     * @param {string} inputDirectory - The directory containing HTML files to optimize.
     */
    private constructor();
    /**
     * Returns the singleton instance of HtmlStylesOptimizer.
     * @param {string} inputDirectory - The directory containing HTML files to optimize.
     * @returns {HtmlStylesOptimizer} The singleton instance.
     */
    static getInstance(inputDirectory: string): HtmlStylesOptimizer;
    /**
     * Recursively reads all directories from the specified directory.
     * @param {string} dir - The directory to read subdirectories from.
     * @returns {string[]} An array of directory paths.
     */
    private readDirectoriesRecursive;
    /**
     * Reads all HTML files from the specified directory.
     * @param {string} dir - The directory to read HTML files from.
     * @returns {string[]} An array of HTML file paths.
     */
    private readHtmlFiles;
    /**
     * Extracts style tags from the given HTML content.
     * @param {string} htmlContent - The HTML content to extract style tags from.
     * @returns {string[]} An array of style tag contents.
     */
    private extractStyleTags;
    /**
     * Removes style tags from the given HTML content.
     * @param {string} htmlContent - The HTML content to remove style tags from.
     * @returns {string} The HTML content without style tags.
     */
    private removeStyleTags;
    /**
     * Inserts unique style tags wrapped in a single <style> tag at the top of the specified HTML file.
     * @param {string} filePath - The path to the HTML file to insert style tags into.
     * @param {Set<string>} styleTags - The set of unique style tag contents to insert.
     */
    private insertUniqueStyleTags;
    /**
     * Main function to optimize styles by deduplicating and consolidating style tags across multiple HTML files.
     */
    run(): void;
}
export default HtmlStylesOptimizer;
